@@ -12,6 +12,7 @@ from .restriction import Restriction
 from .send_type import SendType
 from .giving_type import GivingType
 from .gift_openning import GiftOpenning
+from .auth_errors import AuthErrors
 
 
 __all__ = (
@@ -28,5 +29,6 @@ __all__ = (
     "Restriction",
     "SendType",
     "GivingType",
-    "GiftOpenning"
+    "GiftOpenning",
+    "AuthErrors"
 )
