@@ -2,11 +2,7 @@ from .start_phone_auth import StartPhoneAuth
 from .validate_code import ValidateCode
 from .validate_password import ValidatePassword
 from .sign_out import SignOut
+from .sign_up import SignUp
 
 
-__all__ = (
-    "StartPhoneAuth",
-    "ValidateCode",
-    "ValidatePassword",
-    "SignOut"
-)
+__all__ = ("StartPhoneAuth", "ValidateCode", "ValidatePassword", "SignOut", "SignUp")
