@@ -1,6 +1,4 @@
 from .send_report import SendReport
 
 
-__all__ = (
-    "SendReport",
-)
+__all__ = ("SendReport",)
