@@ -2,7 +2,7 @@ from .jwt_checker import parse_jwt
 from .random import generate_id
 from .protobuf import ProtoBuf
 from .grpc_post import add_header, clean_grpc
-from .int64 import Int64VarintCodec
+from .int64 import decode_list
 from .links import extract_join_token
 from .file_helper import guess_mime_type
 
@@ -13,7 +13,7 @@ __all__ = (
     "ProtoBuf",
     "add_header",
     "clean_grpc",
-    "Int64VarintCodec",
+    "decode_list",
     "extract_join_token",
     "guess_mime_type"
 )
